@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.1709'; 
+$VERSION = '1.1710';
 $VERSION = eval $VERSION; ## no critic
 
 use Config;
@@ -554,12 +554,14 @@ sub _downgrade_known_causes {
         $grade = 'na';
         $msg = 'This platform is not supported';
     }
-    # check for Makefile without 'test' target
-    elsif ( grep { /No rule to make target .test/ims } @{$output} ) {
+    # check for Makefile without 'test' target; there are lots
+    # of variations on the error message, e.g. "target test", "target 'test'", 
+    # "'test'", "`test'" and so on.
+    elsif ( grep { /No rule to make[^\n]+?test/ims } @{$output} ) {
         $grade = 'unknown';
         $msg = 'No make test target';
     }
-    elsif ( grep { /don't know how to make test/ims } @{$output} ) {
+    elsif ( grep { /don't know how to make[^\n]+?test/ims } @{$output} ) {
         $grade = 'unknown';
         $msg = 'No make test target';
     }
